@@ -23,7 +23,14 @@
 #include <QtQml/QQmlContext>
 #include "click.h"
 #include "storageabout.h"
+#include "systemimage.h"
 
+static QObject *siSingletonProvider(QQmlEngine *engine, QJSEngine *scriptEngine)
+{
+    Q_UNUSED(engine)
+    Q_UNUSED(scriptEngine)
+    return new QSystemImage;
+}
 
 void BackendPlugin::registerTypes(const char *uri)
 {
@@ -32,6 +39,9 @@ void BackendPlugin::registerTypes(const char *uri)
     qRegisterMetaType<ClickModel::Roles>();
     qmlRegisterType<ClickModel>(uri, 1, 0, "ClickRoles");
     qmlRegisterType<StorageAbout>(uri, 1, 0, "UbuntuStorageAboutPanel");
+    qmlRegisterSingletonType<QSystemImage>(
+        uri, 1, 0, "SystemImage", siSingletonProvider
+    );
 }
 
 void BackendPlugin::initializeEngine(QQmlEngine *engine, const char *uri)
