@@ -22,6 +22,7 @@
 #include <QtCore/QDateTime>
 #include <QtCore/QDebug>
 #include <QtCore/QProcess>
+#include <QtGlobal>
 #include <QtDBus/QDBusConnection>
 #include <QtDBus/QDBusConnectionInterface>
 #include <QtDBus/QDBusInterface>
@@ -99,6 +100,8 @@ void SecurityPrivacy::slotChanged(QString interface,
             Q_EMIT enableLauncherWhileLockedChanged();
         } else if (property == "EnableIndicatorsWhileLocked") {
             Q_EMIT enableIndicatorsWhileLockedChanged();
+        } else if (property == "EnableFingerprintIdentification") {
+            Q_EMIT enableFingerprintIdentificationChanged();
         }
     } else if (interface == AS_TOUCH_INTERFACE) {
         if (property == "MessagesWelcomeScreen") {
@@ -118,6 +121,7 @@ void SecurityPrivacy::slotChanged(QString interface,
 void SecurityPrivacy::slotNameOwnerChanged()
 {
     // Tell QML so that it refreshes its view of the property
+    Q_EMIT enableFingerprintIdentificationChanged();
     Q_EMIT messagesWelcomeScreenChanged();
     Q_EMIT statsWelcomeScreenChanged();
     Q_EMIT enableLauncherWhileLockedChanged();
@@ -126,6 +130,23 @@ void SecurityPrivacy::slotNameOwnerChanged()
     Q_EMIT hereLicensePathChanged();
 }
 
+bool SecurityPrivacy::getEnableFingerprintIdentification()
+{
+    return m_accountsService.getUserProperty(AS_INTERFACE,
+                                             "EnableFingerprintIdentification").toBool();
+}
+
+void SecurityPrivacy::setEnableFingerprintIdentification(bool enabled)
+{
+    if (enabled == getEnableFingerprintIdentification())
+        return;
+
+    m_accountsService.setUserProperty(AS_INTERFACE,
+                                      "EnableFingerprintIdentification",
+                                      QVariant::fromValue(enabled));
+    Q_EMIT(enableFingerprintIdentificationChanged());
+}
+
 bool SecurityPrivacy::getStatsWelcomeScreen()
 {
     return m_accountsService.getUserProperty(AS_TOUCH_INTERFACE,
@@ -316,7 +337,8 @@ QString SecurityPrivacy::setPassword(QString oldValue, QString value)
     passwdData += value.toUtf8() + '\n' + value.toUtf8() + '\n';
 
     QProcess pamHelper;
-    pamHelper.setProgram("/usr/bin/passwd");
+    // TODO: Decide if this approach is sufficient in a snap world. lp:1616486
+    pamHelper.setProgram(qgetenv("SNAP") + "/usr/bin/passwd");
     pamHelper.start();
     pamHelper.write(passwdData);
     pamHelper.closeWriteChannel();
@@ -381,6 +403,9 @@ QString SecurityPrivacy::setSecurity(QString oldValue, QString value, SecurityTy
         if (!setPasswordModeWithPolicykit(type, oldValue)) {
             setDisplayHint(oldType);
             return badPasswordMessage(oldType);
+        } else {
+            // Successfully enabling Swipe must disable fingerprint auth.
+            setEnableFingerprintIdentification(false);
         }
     } else {
         QString errorText = setPassword(oldValue, value);
