@@ -1,7 +1,7 @@
 
 # -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
 #
-# Copyright (C) 2014, 2015 Canonical Ltd.
+# Copyright (C) 2014-2016 Canonical Ltd.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -15,12 +15,12 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-from time import sleep
 from autopilot import introspection
 from autopilot.exceptions import StateNotFoundError
 from ubuntu_system_settings.utils.i18n import ugettext as _
 
 import logging
+from time import sleep
 import autopilot.logging
 import ubuntuuitoolkit
 import ubuntu_system_settings.utils as utils
@@ -148,8 +148,8 @@ class SystemSettingsMainWindow(ubuntuuitoolkit.MainView):
                 page_center_x,
                 page_center_y - obj.height * 2
             )
-            # avoid a flick
-            sleep(1.0)
+            # avoid a flick, this is very important
+            sleep(0.3)
 
     def scroll_to_and_click(self, obj):
         self.scroll_to(obj)
@@ -164,16 +164,6 @@ class SystemSettingsMainWindow(ubuntuuitoolkit.MainView):
         """ Return 'Choose carrier' page """
         return self.select_single(objectName="chooseCarrierPage")
 
-    @property
-    def storage_page(self):
-        """ Return 'Storage' page """
-        return self.select_single(objectName='storagePage')
-
-    @property
-    def updates_page(self):
-        """ Return 'System Update' page """
-        return self.select_single(objectName='systemUpdatesPage')
-
     @property
     def background_page(self):
         """ Return 'Background' page """
@@ -228,9 +218,6 @@ class CellularPage(ubuntuuitoolkit.UbuntuUIToolkitCustomProxyObjectBase):
     def disable_data(self):
         self._set_data(False)
 
-    def disable_datas(self):
-        self.select_sim_for_data('off')
-
     @autopilot.logging.log_action(logger.debug)
     def _set_data(self, data):
         chk = self.select_single(objectName='data')
@@ -288,6 +275,12 @@ class CellularPage(ubuntuuitoolkit.UbuntuUIToolkitCustomProxyObjectBase):
         chooseApnPage = carrierApnPage.open_apn(sim)
         return chooseApnPage.open(name)
 
+    @autopilot.logging.log_action(logger.debug)
+    def open_apn_page(self, name, sim=None):
+        carrierApnPage = self._click_carrier_apn()
+        chooseApnPage = carrierApnPage.open_apn(sim)
+        return chooseApnPage
+
     @autopilot.logging.log_action(logger.debug)
     def delete_apn(self, name, sim=None):
         carrierApnPage = self._click_carrier_apn()
@@ -817,29 +810,10 @@ class AboutPage(ubuntuuitoolkit.UbuntuUIToolkitCustomProxyObjectBase):
         imei_item = self._get_imei_item()
         return imei_item.value
 
-    def get_os_information(self):
-        os_item = self.select_single(objectName='osItem')
-        return os_item.value
-
-    def get_last_updated_date(self):
-        last_updated_item = self.select_single(objectName='lastUpdatedItem')
-        return last_updated_item.value
-
-    @autopilot.logging.log_action(logger.info)
-    def go_to_check_for_updates(self):
-        check_for_updates_button = self.select_single(
-            objectName='updateButton')
-        check_for_updates_button.swipe_into_view()
-        self.pointing_device.click_object(check_for_updates_button)
-        system_updates_page = self.get_root_instance().wait_select_single(
-            objectName='systemUpdatesPage')
-        system_updates_page.active.wait_for(True)
-        return system_updates_page
-
     @autopilot.logging.log_action(logger.info)
     def go_to_software_licenses(self):
         license_item = self.select_single(
-            ubuntuuitoolkit.listitems.Standard, objectName='licenseItem')
+            'StandardProgression', objectName='licenseItem')
         license_item.swipe_into_view()
         self.pointing_device.click_object(license_item)
         licenses_page = self.get_root_instance().wait_select_single(
@@ -865,19 +839,6 @@ class LicensesPage(ubuntuuitoolkit.UbuntuUIToolkitCustomProxyObjectBase):
         return False
 
 
-class SystemUpdatesPage(ubuntuuitoolkit.UbuntuUIToolkitCustomProxyObjectBase):
-
-    """Autopilot helper for the System Updates page."""
-
-    @classmethod
-    def validate_dbus_object(cls, path, state):
-        name = introspection.get_classname_from_path(path)
-        if name == b'PageComponent':
-            if state['objectName'][1] == 'systemUpdatesPage':
-                return True
-        return False
-
-
 class PhonePage(ubuntuuitoolkit.UbuntuUIToolkitCustomProxyObjectBase):
 
     """Autopilot helper for the Phone page."""
@@ -1296,101 +1257,6 @@ class Services(ubuntuuitoolkit.UbuntuUIToolkitCustomProxyObjectBase):
         pass
 
 
-class ResetPage(ubuntuuitoolkit.UbuntuUIToolkitCustomProxyObjectBase):
-
-    """Autopilot helper for the Reset page."""
-
-    @classmethod
-    def validate_dbus_object(cls, path, state):
-        name = introspection.get_classname_from_path(path)
-        if name == b'PageComponent':
-            if state['objectName'][1] == 'resetPage':
-                return True
-        return False
-
-    @autopilot.logging.log_action(logger.info)
-    def reset_launcher(self):
-        """Reset the launcher.
-
-        :returns: The main system settings page object, that will be visible
-            after the reset is complete.
-
-        """
-        confirm_dialog = self._click_reset_launcher()
-        confirm_dialog.confirm_reset()
-        return self._wait_and_return_main_system_settins_page()
-
-    @autopilot.logging.log_action(logger.debug)
-    def _click_reset_launcher(self):
-        button = self.select_single(objectName='resetLauncher')
-        self.pointing_device.click_object(button)
-        return self.get_root_instance().wait_select_single(
-            objectName='resetLauncherDialog')
-
-    def _wait_and_return_main_system_settins_page(self):
-        main_view = self.get_root_instance().select_single(
-            objectName='systemSettingsMainView')
-        main_view.system_settings_page.active.wait_for(True)
-        return main_view.system_settings_page
-
-    @autopilot.logging.log_action(logger.info)
-    def erase_and_reset_everything(self):
-        """Reset to factory settings.
-
-        :returns: The main system settings page object, that will be visible
-            after the reset is complete.
-
-        """
-        confirm_dialog = self._click_factory_reset()
-        confirm_dialog.confirm_reset()
-        return self._wait_and_return_main_system_settins_page()
-
-    @autopilot.logging.log_action(logger.debug)
-    def _click_factory_reset(self):
-        button = self.select_single(objectName='factoryReset')
-        self.pointing_device.click_object(button)
-        return self.get_root_instance().select_single(
-            objectName='factoryResetDialog')
-
-
-class ResetLauncherConfirmationDialog(
-        ubuntuuitoolkit.UbuntuUIToolkitCustomProxyObjectBase):
-
-    """Autopilot helper for the Reset Launcher Confirmation dialog."""
-
-    @classmethod
-    def validate_dbus_object(cls, path, state):
-        name = introspection.get_classname_from_path(path)
-        if name == b'Dialog':
-            if state['objectName'][1] == 'resetLauncherDialog':
-                return True
-        return False
-
-    @autopilot.logging.log_action(logger.debug)
-    def confirm_reset(self):
-        button = self.select_single('Button', objectName='resetLauncherAction')
-        self.pointing_device.click_object(button)
-
-
-class FactoryResetConfirmationDialog(
-        ubuntuuitoolkit.UbuntuUIToolkitCustomProxyObjectBase):
-
-    """Autopilot helper for the Reset Launcher Confirmation dialog."""
-
-    @classmethod
-    def validate_dbus_object(cls, path, state):
-        name = introspection.get_classname_from_path(path)
-        if name == b'Dialog':
-            if state['objectName'][1] == 'factoryResetDialog':
-                return True
-        return False
-
-    @autopilot.logging.log_action(logger.debug)
-    def confirm_reset(self):
-        button = self.select_single('Button', objectName='factoryResetAction')
-        self.pointing_device.click_object(button)
-
-
 class LanguagePage(ubuntuuitoolkit.UbuntuUIToolkitCustomProxyObjectBase):
 
     """Autopilot helper for the Language page."""
@@ -1534,60 +1400,6 @@ class WifiPage(ubuntuuitoolkit.UbuntuUIToolkitCustomProxyObjectBase):
         if obj.checked != state:
             self.pointing_device.click_object(obj)
 
-    """Connects to hidden network
-
-    :param name: Network name string (SSID)
-    :kwarg security: A string that is either "none", "wpa" or "wep
-    :kwarg password: A string/hex secret
-    :kwarg cancel: A boolean deciding whether we press cancel or not
-
-    :returns: If we are connecting, it returns the dialog,
-        if we cancel, it returns itself
-
-    """
-    @autopilot.logging.log_action(logger.debug)
-    def connect_to_hidden_network(self, name, security='none', username=None,
-                                  password=None, auth=None, protocol=None,
-                                  cancel=False):
-        dialog = self._click_connect_to_hidden_network()
-        dialog._scroll_to_and_click = self._scroll_to_and_click
-        dialog.enter_name(name)
-        utils.dismiss_osk()
-
-        if security:
-            dialog.set_security(security)
-        if auth:
-            dialog.set_auth(auth)
-        if protocol:
-            dialog.set_protocol(protocol)
-        if username:
-            dialog.enter_username(username)
-            utils.dismiss_osk()
-        if password:
-            dialog.enter_password(password)
-            utils.dismiss_osk()
-        if cancel:
-            utils.dismiss_osk()
-            dialog.cancel()
-            return self
-        else:
-            utils.dismiss_osk()
-            dialog.connect()
-            return dialog
-
-    @autopilot.logging.log_action(logger.debug)
-    def _click_connect_to_hidden_network(self):
-
-        # we can't mock the qunitymenu items, so we
-        # have to wait for them to be built
-        sleep(0.5)
-
-        button = self.select_single('*',
-                                    objectName='connectToHiddenNetwork')
-        self._scroll_to_and_click(button)
-        return self.get_root_instance().wait_select_single(
-            objectName='otherNetworkDialog')
-
     @autopilot.logging.log_action(logger.debug)
     def go_to_previous_networks(self):
         return self._click_previous_network()
@@ -1633,79 +1445,6 @@ class OtherNetwork(
                 return True
         return False
 
-    # FIXME: Use ListItem methods instead.
-    @autopilot.logging.log_action(logger.debug)
-    def _expand_list(self, list_name):
-        item_list = self.select_single(
-            '*', objectName=list_name)
-        active_child = item_list.select_single(
-            '*', objectName='listContainer')
-        self._scroll_to_and_click(active_child)
-        # wait for it to expand
-        sleep(0.5)
-        return item_list
-
-    @autopilot.logging.log_action(logger.debug)
-    def enter_name(self, name):
-        self._enter_name(name)
-
-    @autopilot.logging.log_action(logger.debug)
-    def _enter_name(self, name):
-        namefield = self.wait_select_single('TextField',
-                                            objectName='networkname')
-        self._scroll_to_and_click(namefield)
-        namefield.write(name)
-
-    @autopilot.logging.log_action(logger.debug)
-    def enter_username(self, username):
-        self._enter_username(username)
-
-    @autopilot.logging.log_action(logger.debug)
-    def _enter_username(self, username):
-        namefield = self.wait_select_single('TextField',
-                                            objectName='username')
-        self._scroll_to_and_click(namefield)
-        namefield.write(username)
-
-    @autopilot.logging.log_action(logger.debug)
-    def set_security(self, security):
-        """Sets the hidden network's security
-
-        :param security: Either 'none', 'wpa', 'wep', 'wpa-ep', 'dewp', 'leap'
-
-        :returns: None
-        """
-
-        # We only set security if not none, since none is default
-        if security != 'none':
-            self._set_security(security)
-
-    @autopilot.logging.log_action(logger.debug)
-    def _set_security(self, security):
-        s_list = self._expand_list('securityList')
-        item = None
-        if security == 'none':
-            item = s_list.wait_select_single('*', text=_('None'))
-        elif security == 'wpa':
-            item = s_list.wait_select_single('*',
-                                             text=_('WPA & WPA2 Personal'))
-        elif security == 'wep':
-            item = s_list.wait_select_single('*', text=_('WEP'))
-        elif security == 'wpa-ep':
-            item = s_list.wait_select_single('*',
-                                             text=_('WPA & WPA2 Enterprise'))
-        elif security == 'dwep':
-            item = s_list.wait_select_single('*',
-                                             text=_('Dynamic WEP (802.1x)'))
-        elif security == 'leap':
-            item = s_list.wait_select_single('*', text=_('LEAP'))
-        elif security is not None:
-            raise ValueError('security type %s is not valid' % security)
-
-        self.pointing_device.click_object(item)
-        # wait for ui to change
-        sleep(0.5)
-
     @autopilot.logging.log_action(logger.debug)
     def enter_password(self, password):
         self._enter_password(password)
@@ -1717,76 +1456,6 @@ class OtherNetwork(
         self._scroll_to_and_click(pwdfield)
         pwdfield.write(password)
 
-    @autopilot.logging.log_action(logger.debug)
-    def set_protocol(self, protocol):
-        """Sets the hidden network's protocol.
-
-        :param protocol: Either 'pap', 'mschapv2', 'mschap', 'chap', 'gtc',
-                         or 'md5'.
-        """
-        self._set_protocol(protocol)
-
-    @autopilot.logging.log_action(logger.debug)
-    def _set_protocol(self, protocol):
-        p_list = self._expand_list('p2authList')
-        item = None
-        if protocol == 'pap':
-            item = p_list.wait_select_single(text='PAP')
-        elif protocol == 'mschapv2':
-            item = p_list.wait_select_single(text='MSCHAPv2')
-        elif protocol == 'mschap':
-            item = p_list.wait_select_single(text='MSCHAP')
-        elif protocol == 'chap':
-            item = p_list.wait_select_single(text='CHAP')
-        elif protocol == 'gtc':
-            item = p_list.wait_select_single(text='GTC')
-        elif protocol == 'md5':
-            item = p_list.wait_select_single(text='MD5')
-        elif protocol is not None:
-            raise ValueError('protocol type %s is not valid' % protocol)
-
-        self.pointing_device.click_object(item)
-        # wait for ui to change
-        sleep(0.5)
-
-    @autopilot.logging.log_action(logger.debug)
-    def set_auth(self, auth):
-        """Sets the hidden network's protocol.
-
-        :param auth: Either 'tls', 'ttls', 'leap', 'fast' or 'peap'.
-        """
-        self._set_auth(auth)
-
-    @autopilot.logging.log_action(logger.debug)
-    def _set_auth(self, auth):
-        a_list = self._expand_list('authList')
-        item = None
-        if auth == 'tls':
-            item = a_list.wait_select_single(text='TLS')
-        elif auth == 'ttls':
-            item = a_list.wait_select_single(text='TTLS')
-        elif auth == 'leap':
-            item = a_list.wait_select_single(text='LEAP')
-        elif auth == 'fast':
-            item = a_list.wait_select_single(text='FAST')
-        elif auth == 'peap':
-            item = a_list.wait_select_single(text='PEAP')
-        elif auth is not None:
-            raise ValueError('auth type %s is not valid' % auth)
-
-        self.pointing_device.click_object(item)
-        # wait for ui to change
-        sleep(0.5)
-
-    @autopilot.logging.log_action(logger.debug)
-    def cancel(self):
-        self._click_cancel()
-
-    @autopilot.logging.log_action(logger.debug)
-    def _click_cancel(self):
-        button = self.select_single('Button', objectName='cancel')
-        self._scroll_to_and_click(button)
-
     @autopilot.logging.log_action(logger.debug)
     def connect(self):
         self._click_connect()
@@ -1818,7 +1487,7 @@ class PreviousNetworks(
 
     @autopilot.logging.log_action(logger.debug)
     def _select_network(self, name):
-        net = self.select_single('Standard', text=name)
+        net = self.select_single('StandardProgression', text=name)
         self.pointing_device.click_object(net)
 
 
@@ -1852,14 +1521,14 @@ class VpnPage(ubuntuuitoolkit.UbuntuUIToolkitCustomProxyObjectBase):
     @autopilot.logging.log_action(logger.debug)
     def add_vpn(self):
         obj = self.select_single(objectName='addVpnButton')
-        self.pointing_device.click_object(obj)
+        self.get_root_instance().main_view.scroll_to_and_click(obj)
         return self.get_root_instance().wait_select_single(
             objectName='vpnEditor')
 
     @autopilot.logging.log_action(logger.debug)
     def preview_vpn(self, at):
         obj = self.wait_select_single(objectName='vpnListConnection%d' % at)
-        self.pointing_device.click_object(obj)
+        self.get_root_instance().main_view.scroll_to_and_click(obj)
         return self.get_root_instance().wait_select_single(
             objectName='vpnPreviewDialog')
 
@@ -1869,7 +1538,7 @@ class VpnPage(ubuntuuitoolkit.UbuntuUIToolkitCustomProxyObjectBase):
         change_button = diag.wait_select_single(
             objectName='vpnPreviewChangeButton'
         )
-        self.pointing_device.click_object(change_button)
+        self.get_root_instance().main_view.scroll_to_and_click(change_button)
         return self.get_root_instance().wait_select_single(
             objectName='vpnEditor')
 
@@ -1920,10 +1589,16 @@ class VpnEditor(
 
     @autopilot.logging.log_action(logger.debug)
     def set_openvpn_server(self, server):
+        self.get_root_instance().main_view.scroll_to(
+            self._openvpn_server_field
+        )
         self._openvpn_server_field.write(server)
 
     @autopilot.logging.log_action(logger.debug)
     def set_openvpn_custom_port(self, port):
+        self.get_root_instance().main_view.scroll_to(
+            self._openvpn_custom_port_toggle
+        )
         self._openvpn_custom_port_toggle.check()
         # XXX: workaround for lp:1546559, i.e. we need to wait
         # some time between writing to the API.
@@ -1936,7 +1611,8 @@ class VpnEditor(
 
     @autopilot.logging.log_action(logger.debug)
     def set_openvpn_file(self, field, paths):
-        self.pointing_device.click_object(field)
+        utils.dismiss_osk()
+        self.get_root_instance().main_view.scroll_to_and_click(field)
 
         # Wait for expanded animation.
         sleep(0.5)
@@ -1944,6 +1620,7 @@ class VpnEditor(
         # file = field.wait_select_single(objectName='vpnFileSelectorItem0')
         choose = field.wait_select_single(objectName='vpnFileSelectorItem1')
         self.pointing_device.click_object(choose)
+        self.get_root_instance().main_view.scroll_to_and_click(choose)
         file_dialog = self.get_root_instance().wait_select_single(
             objectName='vpnDialogFile'
         )
